export interface IPsySegResponses {
    status: boolean
    licenseControl?: string
    data?: ImageData
    modelSize?: {
        width: number
        height: number
    }
}
export interface IPsySegEffectParams {
    mode?: string
    erode?: number
    enhanceFrame?: boolean
    gamma?: number
    isSkipAlpha?: boolean
    blur?: number
    dstSize?: {
        width: number
        height: number
    }
    overlaySize?: number
    overlayPosition?: number
    shape?: string
    isRemoveBlob?: boolean
}

export interface IPsySegProps {
    psySegWasmURL?: string
    tfliteWasmURL?: string
    tfliteSimdWasmURL?: string
    segmentationModelURL?: string
    license?: string
    accessToken?: string
    accessKey?: string
}

export default class PsySeg {
    init(props?: IPsySegProps): Promise<IPsySegResponses>

    version(): string

    replaceBackground(
        inputColor: ImageData,
        inputBackground: ImageData,
        effectParams?: IPsySegEffectParams
    ): Promise<IPsySegResponses>

    blurBackground(inputColor: ImageData, effectParams?: IPsySegEffectParams): Promise<IPsySegResponses>

    removeBackground(inputColor: ImageData, effectParams?: IPsySegEffectParams): Promise<IPsySegResponses>

    runAlpha(inputColor: ImageData, effectParams?: IPsySegEffectParams): Promise<IPsySegResponses>

    toMask(inputColor: ImageData, effectParams?: IPsySegEffectParams): Promise<IPsySegResponses>

    shapeForeground(
        inputColor: ImageData,
        inputBackground: ImageData,
        effectParams?: IPsySegEffectParams
    ): Promise<IPsySegResponses>

    maskShapeBackground(inputColor: ImageData, effectParams?: IPsySegEffectParams): Promise<IPsySegResponses>
}
